########################################################################
# File:    tasks_helper.rb                                             #
#          Hipposoft 2008                                              #
#                                                                      #
# Purpose: Support functions for views related to Task objects. See    #
#          controllers/tasks_controller.rb for more.                   #
#                                                                      #
# History: 04-Jan-2008 (ADH): Created.                                 #
########################################################################

module TasksHelper

  # Return HTML suitable for an edit form, providing a grouped list of
  # projects that can be assigned to the task. The list is grouped by
  # customer in default customer sort order, along with a 'None' entry
  # for unassigned projects. Pass the task object being edited.

  def taskhelp_project_selector( task )
    return apphelp_project_selector(
      'task_project_id',
      'task[project_id]',
      task.project_id
    )
  end

  # Return HTML showing the remaining hours on a task, or a label
  # indicating overrun. Pass the number of hours and the expected
  # task duration.

  def taskhelp_remaining( hours, duration )
    if ( hours > duration and duration != 0 )
      return '<span class="overrun">Overrunning</span>'
    else
      return apphelp_hours( 0 ) if ( duration == 0 )
      return apphelp_hours( duration - hours )
    end
  end

  # Return HTML showing the number of hours overrun on a task, or
  # a label indicating no overrun. Pass the number of hours and the
  # expected task duration.

  def taskhelp_overrun( hours, duration )
    if ( hours > duration and duration != 0 )
      return apphelp_hours( hours - duration )
    else
      return '<span class="no_overrun">None</span>'
    end
  end

  # Return a name of a given task's associated project, for use in list views.

  def taskhelp_project( task )
    reutnr '-' if ( task.project.nil? )
    return link_to( task.project.title, project_path( task.project ) )
  end

  # Return a name of a given task's associated customer, for use in list views.

  def taskhelp_customer( task )
    return '-' if ( task.project.nil? or task.project.customer.nil? )
    return link_to( task.project.customer.title, customer_path( task.project.customer ) )
  end

  # Return a formatted duration for the given task, for use in list views.

  def taskhelp_duration( task )
    return apphelp_string_hours( task.duration.to_s, '0', '?' )
  end

  # Return list actions appropriate for the given task.

  def taskhelp_actions( task )
    if ( @current_user.admin? or ( task.active and @current_user.manager? ) )
      actions = [ 'edit' ]
      actions.push( 'delete' ) if ( @current_user.admin? )
    else
      actions = []
    end

    actions.push( 'show' )
    return actions
  end
end
